@@ -3,10 +3,12 @@ use parent qw(Encode::Encoding);
 use strict;
 use warnings;
 use utf8;
+use Lingua::AR::Vowels;
 
 __PACKAGE__->Define(qw(Franco-Arabic Arabizy));
 
 # ABSTRACT: Does transliteration from chat Arabic
+our $VERSION = '0.005'; # VERSION
 
 sub import { # imports Encode
     require Encode;
@@ -19,10 +21,11 @@ sub decode($$;$){
 
     $str =~ s/\b[ae]l/ال/g;
     $str =~ s/(2|\b)e/إ/g;
-    $str =~ s/(2|\b)[ou]/أُ/g;
-    $str =~ s/2|\ba/أ/g;
-    $str =~ s/[aoyei]2\b/ء/g;
     $str =~ s/o2/ؤ/g;
+    $str =~ s/^2?[ou]/أُ/g;
+    $str =~ s/2a/أ/g;
+    $str =~ s/(?![aoyei])2/ء/g;
+    $str =~ s/2|\ba/أ/g;
 
     $str =~ s/3'/غ/g;
     $str =~ s/7'/خ/g;
@@ -32,7 +35,9 @@ sub decode($$;$){
     $str =~ s/sh/ش/g;
     $str =~ s/ah\b/ة/g;
     $str =~ s/ss/ص/g;
+    $str =~ s/ee/ي/g;
     $str =~ s/th/ث/g;
+    $str =~ s/oo/و/g;
     $str =~ s/zz|6'/ظ/g;
 
 
@@ -44,12 +49,14 @@ sub decode($$;$){
 
     $str =~ tr
         { a b c d e f g h i j k l m n o p q r s t u v w x y z }
-        { ا ب _ د ي ف ج ه ي ج ك ل م ن و پ ق ر س ت و ڤ و _ ي ز };
+        { ا ب c د e ف ج ه ي ج ك ل م ن و پ ق ر س ت و ڤ و x ي ز };
     
     $str =~ tr
         { , ; ? }
         { ، ؛ ؟ };
 
+    $str =~ s/\w//ga; # strip untranslated characters
+
     $_[1] = '' if $chk;
     return $str;
 }
@@ -91,7 +98,7 @@ Currently nothing more than a chain of C<tr>icks à la:
 
 =head1 GIT REPOSITORY
 
-L<http://github.com/a3f/Encode-Arabic-Franco>
+L<http://github.com/athreef/Encode-Arabic-Franco>
 
 =head1 SEE ALSO
 
